# Fast Vindex

**fast-vindex** is a faster and more flexible alternative to Dask's built-in `vindex` function, designed to improve performance when working with complex or high-dimensional array indexing.

## Installation

`fast_vindex` is a pure python package. It can easily be installed with pip or conda.

```bash
pip install fast-vindex
```

## Documentation

Learn more about `fast_vindex` in its official documentation at [https://odatis-public.gitlab-pages.ifremer.fr/fast_vindex](https://odatis-public.gitlab-pages.ifremer.fr/fast_vindex)
